function pres=algo_BCVMFB_wav(X,pdata,palgo)

%function pres=algo_BCVMFB_wav(X,pdata,palgo)
%
%Impl�mentation de l'algorihme BCVMFB avec des ondelettes
%
% INPUTS :
%           X : observations
%           pdata : parameters of the data
%               pdata.Ai : initial mixing matrix
%               pdata.Si : initial sources estimation
%               pdata.A : original mixing matrix
%               pdata.S : original sources
%           palgo : parameters needed for the algorithm
%           palgo.fwt : wavelets parameters
%
% OUTPUTS :
%           pres : stucture containing the result
%           pres.A : estimated mixing matrice
%           pres.S : estimated sources
%           pres.cost : cost function
%           pres.amari : amari indexes at each iteration if original data
%           available
%           pres.SDR,pres.SIR,pres.SAR : BSS eval indexes at each iteration
%           if original data available

%Cost function
%cout global avec regularisation
cost=zeros(palgo.niter+1,1);
%metrique a chaque iteration eventuellement
if isfield(pdata,'A')
    amari = zeros(palgo.niter+1,1);
end
if isfield(pdata,'S')
    SDR = zeros(palgo.niter+1,size(pdata.S,1));
    SIR = zeros(palgo.niter+1,size(pdata.S,1));
    SAR = zeros(palgo.niter+1,size(pdata.S,1));
end

%on initialise A et S
A=pdata.Ai;
S=pdata.Si;

%on raccourci la TF ondelettes
F=palgo.F;
Fstar=palgo.Fstar;

%on calcule les indices de performances initiaux
if isfield(pdata,'SigmaX')
    amari(1) = amari_metric(pdata.A,pdata.SigmaX.*A);
else
    amari(1) = amari_metric(pdata.A,A);
end
[SDR(1,:),SIR(1,:),SAR(1,:)]=computeSxR(pdata.S,S);
FS=F(S);
cost(1)=1/2*norm(X-A*S,'fro')^2+palgo.alpha_A*sum(abs(A(:)).^palgo.p_A)+palgo.alpha_S*sum(abs(FS(:)).^palgo.p_S);

%h = waitbar(0,['wBCVMFB-',palgo.precond,', please wait...']);

for n=1:palgo.niter
    
    %on garde en memoire l'iteration precedente
    A_old=A;
    S_old=S;
    
    %print the iteration number
    if rem(n,100)==0
        %        waitbar(n/palgo.niter,h);
        fprintf('  iteration %d\n',n);
    end
    
    %NOTE : on met � jour alternativement A et S mais on pourrait choisir
    %les blocs al�atoirement
    
    %pre conditionning matrices
    if (rem(n,2)==0)
        switch palgo.precond
            case 'LS'
                % Lee et Seung
                P_A=A*(S*S')./A;
            case 'Lips'
                % Lipschitz constant
                P_A = max(abs(eig(S*S')))*ones(size(A));
        end
    else
        switch palgo.precond
            case 'LS'
                % Lee et Seung
                P_S=(A'*A)*S./S;
            case 'Lips'
                % Lipschitz constant
                P_S=max(abs(eig(A'*A)))*ones(size(S));
        end
    end
    
    %calculation of the tilda matrices (gradient)
    if (rem(n,2)==0)
        A_tilda=A-palgo.gamma*((A*S-X)*S')./P_A;
    else
        S_tilda=S-palgo.gamma*(A'*(A*S-X))./P_S;
    end
    
    %calculation of the proximity operator (see (60) (61) ref. "A block coordinate VMFB algo"
    if (rem(n,2)==0)
        A=min(palgo.eta_sup,max(palgo.eta_inf,proxpowerp(A_tilda,palgo.p_A,palgo.gamma*palgo.alpha_A./P_A)));
    else
        S=min(palgo.eta_sup,max(palgo.eta_inf,Fstar(proxpowerp(F(S_tilda),palgo.p_S,palgo.gamma*palgo.alpha_S./P_S))));
    end
    %during A (resp. S) is chosen, S (resp. A) is kept unchanged
    
    if pdata.Norm.FlagIter
        [A, S] = normalise(A,S,pdata);
    end
    
    %calculation of the cost function (unconstrained case)
    FS=F(S);
    cost(n+1)=1/2*norm(X-A*S,'fro')^2+palgo.alpha_A*sum(abs(A(:)).^palgo.p_A)+palgo.alpha_S*sum(abs(FS(:)).^palgo.p_S);
    
    % si on a les data originales, on peut calculer des metriques a chaque
    % iteration
    if isfield(pdata,'A')
        if isfield(pdata,'SigmaX')
            amari(n+1) = amari_metric(pdata.A,pdata.SigmaX.*A);
        else
            amari(n+1) = amari_metric(pdata.A,A);
        end
    else
        amari=false;
    end
    if isfield(pdata,'S')
        [SDR(n+1,:),SIR(n+1,:),SAR(n+1,:)]=computeSxR(pdata.S,S);
    else
        SDR = false;SIR=false;SAR=false;
    end
    
    %critere d'arret calculable que si palgo.niter>1
    if palgo.niter > 1
        if stopping_criterion(A,A_old,S,S_old,cost,n,palgo.stop)
            fprintf('!!! Convergence criterion(s) reached after %d iterations !!!\n',n);
            pres.niter=n;
            break;
        elseif n==palgo.niter
            disp('!!! Maximum number of iterations reached !!!');
            pres.niter=n;
        end
    else
        disp('!!! Maximum number of iteration (=1) reached !!!');
        pres.niter=n;
    end
end

% construction de la structure de sortie.
% on crop les vecteurs pour garder uniquement les valeurs calculees
array_crop = @(X) X(1:pres.niter,:);
if isfield(pdata,'SigmaX')
    pres.A=pdata.SigmaX.*A;
else
    pres.A=A;
end
pres.S=S;
pres.cost=array_crop(cost);
pres.amari=array_crop(amari);
pres.SDR=array_crop(SDR);
pres.SIR=array_crop(SIR);
pres.SAR=array_crop(SAR);