function pres=algo_PALS(X,pdata,palgo)

%function pres=algo_PALS(X,pdata,palgo)
%
%algo_PALS  for projected alternated least square with nonnegative
%constraint
%
% INPUTS :
%           X :  Matrix containing the mixings (spectra to be separated)
%           pdata : parameters of the data
%               pdata.Ai : initial mixing matrix
%               pdata.Si : initial sources estimation
%               pdata.A : original mixing matrix
%               pdata.S : original sources
%           palgo : parameters needed for the algorithm
%
% OUTPUTS :
%           pres : stucture containing the result
%           pres.A : estimated mixing matrice
%           pres.S : estimated sources
%           pres.cost : cost function
%           pres.amari : amari indexes at each iteration if original data
%           available
%           pres.SDR,pres.SIR,pres.SAR : BSS eval indexes at each iteration
%           if original data available

%Cost function
%cout global avec regularisation
cost=zeros(palgo.niter+1,1);
%metrique a chaque iteration eventuellement
if isfield(pdata,'A')
    amari = zeros(palgo.niter+1,1);
end
if isfield(pdata,'S')
    SDR = zeros(palgo.niter+1,size(pdata.S,1));
    SIR = zeros(palgo.niter+1,size(pdata.S,1));
    SAR = zeros(palgo.niter+1,size(pdata.S,1));
end

%on initialise A et S
A=pdata.Ai;
S=pdata.Si;

%on calcule les indices de performances initiaux
if isfield(pdata,'SigmaX')
    amari(1) = amari_metric(pdata.A,pdata.SigmaX.*A);
else
    amari(1) = amari_metric(pdata.A,A);
end
[SDR(1,:),SIR(1,:),SAR(1,:)]=computeSxR(pdata.S,S);
cost(1)=1/2*norm(X-A*S,'fro')^2;

for n=1:palgo.niter
    
    %on garde en memoire l'iteration precedente
    A_old=A;
    S_old=S;
    
    %print the iteration number
    if rem(n,100)==0
        fprintf('%d\n',n);
    end
    
    [A, S] = alsm(X, A);
    
    if pdata.Norm.FlagIter
        [A, S] = normalise(A,S,pdata);
    end
    
    %calculation of the cost function (unconstrained case)
    cost(n+1)=1/2*norm(X-A*S,'fro')^2;
    
    % si on a les data originales, on peut calculer des metriques a chaque
    % iteration
    if isfield(pdata,'A')
        if isfield(pdata,'SigmaX')
            amari(n+1) = amari_metric(pdata.A,pdata.SigmaX.*A);
        else
            amari(n+1) = amari_metric(pdata.A,A);
        end
    else
        amari=false;
    end
    if isfield(pdata,'S')
        [SDR(n+1,:),SIR(n+1,:),SAR(n+1,:)]=computeSxR(pdata.S,S);
    else
        SDR = false;SIR=false;SAR=false;
    end
    
    %critere d'arret calculable que si palgo.niter>1
    if palgo.niter > 1
        if stopping_criterion(A,A_old,S,S_old,cost,n,palgo.stop)
            fprintf('!!! Convergence criterion(s) reached after %d iterations !!!\n',n);
            pres.niter=n;
            break;
        elseif n==palgo.niter
            disp('!!! Maximum number of iterations reached !!!');
            pres.niter=n;
        end
    else
        disp('!!! Maximum number of iteration (=1) reached !!!');
        pres.niter=n;
    end
end

% construction de la structure de sortie.
% on crop les vecteurs pour garder uniquement les valeurs calculees
array_crop = @(X) X(1:pres.niter,:);
if isfield(pdata,'SigmaX')
    pres.A=pdata.SigmaX.*A;
else
    pres.A=A;
end
pres.S=S;
pres.cost=array_crop(cost);
pres.amari=array_crop(amari);
pres.SDR=array_crop(SDR);
pres.SIR=array_crop(SIR);
pres.SAR=array_crop(SAR);