function [A, S] = alsm(X, A)

% function [A, S] = alsm(X, A)
%
% Standard Alternating Least Squares Algorithm which minimises 
% the frobenius norm between X and AS
%
% min ||X - AS||_F
%
% INPUTS:
%           X: mixtures
%           A: initial mixing matrice A
% OUTPUTS:
%           A: estimated A
%           S: estimated S


% We compute the explicit minimizer S
A_transpose = A.';
S = (A_transpose*A) \ (A_transpose*X);
% We put the negative entries of S to zero.
S(S<0)=0;

% We do the same steps with the minimizer A
S_transpose = S.';
A = (X*S_transpose) / (S*S_transpose);
A(A<0)=0;

end