function [A, S] = alsm_L1(X, A, l)

% function [A, S] = alsm_L1(X, A, l)
% Regularized Alternating Least Squares Algorithm which minimises 
% the frobenius norm between X and AS with a sparsitu constraint on S
% It minimises the following optimization problem:
%
% min ||X - AS||_F + l * ||S||_1
%
% INPUTS:
%           X: mixtures
%           A: initial mixing matrice A
%           l: regularization parameter
% OUTPUTS:
%           A: estimated A
%           S: estimated S

A_transpose = A.';
S = (A_transpose*A) \ (A_transpose*X);
% This projection is due to the regularization function
S = proxpowerp(S,1,l*ones(size(S)));
S(S<0)=0;

S_transpose = S.';
A = (X*S_transpose) / (S*S_transpose);
A(A<0)=0;

end