function [] = DisplayBSSSummary(BSS_sum)
%DisplayBSSSummary Display summarized BSS results
%   usage:  DisplayBSSSummary(BSS_sum)
%
% Input Variables:
%   BSS_sum: summary of BSS of NMR mixtures: structure with fields
%       resname: identifier (dataset + algorithm)
%       iter: number of iterations
%       amari_opt: optimal value of Amari index
%       amari_opt_ind: iteration for optimal Amari index
%       amari_final: Amari index value at convergence
%       SDR_opt: optimal value of SDR
%       SDR_opt_ind: iteration for optimal SDR
%       SDR_final: SDR value at convergence
%       SIR_opt: optimal value of SIR
%       SIR_opt_ind: iteration for optimal SIR
%       SIR_final: SIR value at convergence
%       SAR_opt: optimal value of SAR
%       SAR_opt_ind: iteration for optimal SAR
%       SAR_final: SAR value at convergence


NbSrc = size(BSS_sum.SDR_final,2);

fprintf('\n ---> %s. Converged in %d iterations\n',BSS_sum.resname,BSS_sum.iter);
fprintf('  Final Amari index: %f;',BSS_sum.amari_final);
fprintf(' Optimal Amari index: %f',BSS_sum.amari_opt);
fprintf(' at iteration: %d\n',BSS_sum.amari_opt_ind);
for src=1:NbSrc
    fprintf('  Source %d:  Final SDR: %f;',src,BSS_sum.SDR_final(src));
    fprintf(' Optimal SDR: %f',BSS_sum.SDR_opt(src));
    fprintf(' at iteration: %d\n',BSS_sum.SDR_opt_ind(src));
    fprintf('             Final SIR: %f;',BSS_sum.SIR_final(src));
    fprintf(' Optimal SIR: %f',BSS_sum.SIR_opt(src));
    fprintf(' at iteration: %d\n',BSS_sum.SIR_opt_ind(src));
    fprintf('             Final SAR: %f;',BSS_sum.SAR_final(src));
    fprintf(' Optimal SAR: %f',BSS_sum.SAR_opt(src));
    fprintf(' at iteration: %d\n',BSS_sum.SAR_opt_ind(src));
end
fprintf('\n');
end

