function res_summary = SummarizeBSSResults(res,resname)
%SummarizeBSSResults: summarize source separation results indices
%   usage:  res_summary = SummarizeBSSResults(res,resname)
%
% Input variables:
%   res: result of BSS, structure that must contain at least fields
%       - amari
%       - SDR
%       - SIR
%       - SAR
%   resname:
%
%   Output variables:
%   res_summary: structure containing the following fields
%       - iter
%       - amari_opt: optimal value of Amari index
%       - amari_opt_ind: iteration for optimal Amari index
%       - amari_final: final value of Amari index
%       - SDR_opt: optimal value of SDR
%       - SDR_opt_ind: iteration for optimal SDR
%       - SDR_final: final value of SDR
%       - SIR_opt: optimal value of SIR
%       - SIR_opt_ind: iteration for optimal SIR
%       - SIR_final: final value of SIR
%       - SAR_opt: optimal value of SAR
%       - SAR_opt_ind: iteration for optimal SAR
%       - SAR_final: final value of SAR

res_summary.resname = [resname,': ',res.algname];

res_summary.iter = length(res.amari);

[res_summary.amari_opt,res_summary.amari_opt_ind] = min(res.amari);
res_summary.amari_final = res.amari(end);

[res_summary.SDR_opt,res_summary.SDR_opt_ind] = max(res.SDR);
res_summary.SDR_final = res.SDR(end,:);

[res_summary.SIR_opt,res_summary.SIR_opt_ind] = max(res.SIR);
res_summary.SIR_final = res.SIR(end,:);

[res_summary.SAR_opt,res_summary.SAR_opt_ind] = max(res.SAR);
res_summary.SAR_final = res.SAR(end,:);

end

