function [SDR,SIR,SAR] = computeSxR(Sref,S)
% computeSxR: compute SDR, SIR et SAR for each source, using BSS eval
% Usage:    [SDR,SIR,SAR] = computeSxR(Sref,S)
% INPUTS :
%           Sref : True sources (original data)
%           S : Estimated sources
%
% OUTPUT :
%           SDR,SIR,SAR : distortion measures

SDR = zeros(1,size(S, 1));
SIR = zeros(1,size(S, 1));
SAR = zeros(1,size(S, 1));

[S, ~] = permuteSources(Sref, S);
for s = 1:size(S, 1)
    [s_target, e_interf, e_artif] = bss_decomp_gain(S(s, :), s, Sref);
    [sdr, sir, sar] = bss_crit(s_target, e_interf, e_artif);
    SDR(s) = sdr;
    SIR(s) = sir;
    SAR(s) = sar;
end