function [S_est, perm] = permuteSources(S_ref, S_est)
% function [S_est, perm] = permuteSources(S_ref, S_est)
% permutation: Fix the permutation indeterminacy of the separation
% by solving the stable mariage problem. In this way the matching is
% "bijective" . Each estimated source (row of S_est) can be matched to one
% and only one reference source (S_ref)
% Usage:    [S_est, perm] = permutation(S_ref, S_est)
% Input variables:
%   S_est: estimated sources, NbSrc * NbPts array
%   S_ref: reference sources, NbSrc * NbPts array
%
% Output variables:
%   S_est: reordered sources, NbSrc * NbPts array
%   perm: permutation, vector of length NbSrC 

NbSrc = size(S_est, 1);


S_est_n = normalise_rows_L2(S_est);
S_ref = normalise_rows_L2(S_ref);

% Preference list
[~, S_est_pref_list] = sort(S_est_n * S_ref.', 2, 'descend');
[~, S_ref_pref_list] = sort(S_ref * S_est_n.', 2, 'descend');

perm = gale_shapley(NbSrc,S_est_pref_list,S_ref_pref_list);

S_est = S_est(perm, :);

end