function pr = proxpowerp(x,p,gamma)

% pr = proxpowerp(x,p,gamma,y)
%
% Computation of the proximity operator of gamma*|x|^p
%
% INPUT:
%   x: coefficients to which proximity operator is applied
%   p: power of the lp-norm
%   gamma: coefficient in front of the lp-norm
%
% OUTPUT:
%   pr: proximity operator of gamma*|x|^p


[K,L1,L2]=size(x);
tmp=gamma;
gamma=zeros(K,L1,L2);
for k=1:K
    gamma(k,:,:)=reshape(tmp(k,:),L1,L2);
end
clear tmp;

switch p
    case 1
        pr = max(abs(x)-gamma,0).*sign(x);
    case 2
        pr = x./(1+2*gamma);
    case 3
        pr =sign(x).*(sqrt(1+12*gamma.*abs(x))-1)./(6*gamma);
    case 4
        pr = sqrt(x.^2+1./(27*gamma));
        pr =1./(8*gamma).^(1/3).*((x+pr).^(1/3)-(-x+pr).^(1/3));
    otherwise
        error('unknown prox');
end