
function flagStop = stopping_criterion(A,A_old,S,S_old,cost,n,pstop)

%function that computes the stopping criterions
%
% INPUTS :
%           A : current A^n
%           A_old : previous A^{n-1}
%           S : current S^n
%           S_old : previous S^{n-1}
%           cost : value of the cost function along with the iterations
%           n : current iteration
%           pstop : tolerance
%
% OUTPUT :
%           flagStop : true if the algorithm should stop, false otherwise



if pstop.DifA
    flagdifA = norm(A_old - A, 'fro') / norm(A_old, 'fro') < pstop.seuil;
else
    %si un drapeau n'est pas active alors il est vrai par defaut
    flagdifA = true;
end

if pstop.DifS
    flagdifS = norm(S_old - S, 'fro')/norm(S_old, 'fro') < pstop.seuil;
else
    flagdifS = true;
end

if pstop.ObjFct
    if n==1
        flagObjFct = false;
    else
        flagObjFct = abs(cost(n)-cost(n-1))/cost(n-1) < pstop.seuil;
    end
else
    flagObjFct = true;
end

flagStop = flagdifA && flagdifS && flagObjFct;

%Si on a fait toutes les itrations mais que l'algo ne s'est pas arrt
if flagStop~=true && n==length(cost)
    disp('!!! Convergence criterion(s) NOT reached !!!');
    fprintf('Tolerance on A = %d \n',norm(A_old - A, 'fro') / norm(A_old, 'fro'));
    fprintf('Tolerance on S = %d \n',norm(S_old - S, 'fro')/norm(S_old, 'fro'));
    fprintf('Tolerance on cost fct = %d \n',abs(cost(n)-cost(n-1))/cost(n-1));
end

